void setupDACADC()
{

  //setup DAC with DMA

  dma.begin(true); // allocate the DMA channel first

  SIM_SCGC2 |= SIM_SCGC2_DAC0; // enable DAC clock
  DAC0_C0 = DAC_C0_DACEN | DAC_C0_DACRFS; // enable the DAC module, 3.3V reference

  // slowly ramp up to DC voltage, approx 1/4 second
  for (int16_t i = 0; i < 2048; i += 8)
  {
    *(volatile int16_t *)&(DAC0_DAT0L) = i;
    delay(1);
  }

  // set the programmable delay block to trigger DMA requests
  SIM_SCGC6 |= SIM_SCGC6_PDB; // enable PDB clock
  PDB0_IDLY = 0; // interrupt delay register
  PDB0_MOD = 0; //PDB_PERIOD; // modulus register, sets period

  PDB0_SC = PDB_CONFIG | PDB_SC_LDOK; // load registers from buffers
  PDB0_SC = PDB_CONFIG | PDB_SC_SWTRIG; // reset and restart
  PDB0_CH0C1 = 0x0101; // channel n control register?

  dma.sourceBuffer(dacOut, sizeof(dacOut));
  // dma.destination(*(volatile uint16_t *) & (DAC0_DAT0L));
  dma.destination(*(volatile unsigned int *) & (DAC0_DAT0L));
  dma.triggerAtHardwareEvent(DMAMUX_SOURCE_PDB);
  dma.enable();


  //Setup ADC

  adc->setReference(ADC_REFERENCE::REF_EXT);

  // ADC0 - CV INPUTS
  adc->setAveraging(1); // set number of averages
  adc->setResolution(12); // set bits of resolution
  adc->setConversionSpeed(ADC_CONVERSION_SPEED::LOW_SPEED);
  adc->setSamplingSpeed(ADC_SAMPLING_SPEED::LOW_SPEED);
  //launch ADC0 - CVs
  adc->startSingleRead(bitsCV, ADC_0);

  // setup "Timer" slow timer for CV sampling
  sampleTimeCV = micros();
  cvSampleRate = 255; // measure every 255 uSec

  // ADC1 - AUDIO INPUT
  adc->setAveraging(1, ADC_1);
  adc->setResolution(16, ADC_1);
  adc->setConversionSpeed(ADC_CONVERSION_SPEED::HIGH_SPEED, ADC_1);
  adc->setSamplingSpeed(ADC_SAMPLING_SPEED::HIGH_SPEED, ADC_1);

}

